summaryrefslogtreecommitdiff
path: root/ui/gtk/summary_dlg.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2012-05-20 08:56:06 +0000
committerGuy Harris <guy@alum.mit.edu>2012-05-20 08:56:06 +0000
commit4a9b825c49a228b6456fbf24731aadcdd47d2c4e (patch)
tree55a654e285d7298213738a4b58db5e65a09e59d8 /ui/gtk/summary_dlg.c
parentacc2a3706bf20e518f63492f424d0276d70e7e32 (diff)
downloadwireshark-4a9b825c49a228b6456fbf24731aadcdd47d2c4e.tar.gz
Change the "user_saved" member of a capture_file structure to
"unsaved_changes", and have it be TRUE iff changes have been made to the file since it was read - *not* if it's a temporary file from a live capture. Check the "is_tempfile" member, and the "unsaved_changes" member, when appropriate. Just have a set_toolbar_for_capture_file() routine that updates the "save", "close", and "reload" toolbar as appropriate, given a capture_file structure - absorb the function of set_toolbar_for_unsaved_capture_file() into it. svn path=/trunk/; revision=42721
Diffstat (limited to 'ui/gtk/summary_dlg.c')
-rw-r--r--ui/gtk/summary_dlg.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ui/gtk/summary_dlg.c b/ui/gtk/summary_dlg.c
index 690eee669c..bf0ba04f96 100644
--- a/ui/gtk/summary_dlg.c
+++ b/ui/gtk/summary_dlg.c
@@ -144,8 +144,8 @@ summary_comment_text_buff_save_cb(GtkWidget *w _U_, GtkWidget *view)
/*g_warning("The new comment is '%s'",new_packet_comment);*/
summary_update_comment(&cfile, new_comment);
- /* Mark the file as unsaved, caues a popup asking to save the file if we quit the file */
- cfile.user_saved = FALSE;
+ /* Mark the file as having unsaved changes; this causes a popup asking to save the file if we quit the file */
+ cfile.unsaved_changes = TRUE;
set_menus_for_capture_file(&cfile);
}